lines — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# lines

Lines message IDs recognised by Pyskool. The text of the lines messages themselves are defined in the [LinesMessages] section of the ini file.

`lines.` `BACK_TO_SKOOL` = 'BACK_TO_SKOOL'

  Eric should be back in the boys’ skool by now.

`lines.` `BE_PUNCTUAL` = 'BE_PUNCTUAL'

  Eric showed up for class while the swot was grassing on him for being absent.

`lines.` `COME_ALONG_PREFIX` = 'COME_ALONG'

  Prefix for the lines message IDs used when Eric’s teacher is fetching him.

`lines.` `GET_ALONG` = 'GET_ALONG'

  Eric should be in the dinner hall, assembly hall, or a particular classroom by now.

`lines.` `GET_OFF_PLANT` = 'GET_OFF_PLANT'

  Eric is standing on a plant.

`lines.` `GET_OUT` = 'GET_OUT'

  Eric is somewhere he should never be (such as the head’s study).

`lines.` `GET_UP` = 'GET_UP'

  Eric is sitting or lying on the floor.

`lines.` `NEVER_AGAIN` = 'NEVER_AGAIN'

  Somebody knocked a teacher over.

`lines.` `NO_BIKES` = 'NO_BIKES'

  Eric is riding the bike inside the boys’ skool.

`lines.` `NO_CATAPULTS` = 'NO_CATAPULTS'

  Eric is firing his catapult.

`lines.` `NO_HITTING` = 'NO_HITTING'

  Eric is throwing a punch.

`lines.` `NO_JUMPING` = 'NO_JUMPING'

  Eric is jumping.

`lines.` `NO_SITTING_ON_STAIRS` = 'NO_SITTING_ON_STAIRS'

  Eric is sitting on the stairs.

`lines.` `NO_STINKBOMBS` = 'NO_STINKBOMBS'

  Eric dropped a stinkbomb.

`lines.` `NO_TALES` = 'NO_TALES'

  The swot told a tale.

`lines.` `NO_WATERPISTOLS` = 'NO_WATERPISTOLS'

  Eric is firing a water pistol.

`lines.` `NO_WRITING` = 'NO_WRITING'

  Eric is writing on a blackboard.

`lines.` `SIT_DOWN` = 'SIT_DOWN'

  Eric is standing up in class when he should be sitting down.

`lines.` `SIT_FACING_STAGE` = 'SIT_FACING_STAGE'

  Eric is sitting down facing the wrong way in assembly.

`lines.` `STAY_IN_CLASS` = 'STAY_IN_CLASS'

  Eric left the classroom and then returned while the swot was grassing on him for being absent.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »